@@ -211,6 +211,8 @@ class CreateAsyncRecognitionTaskRequest(AbstractModel):
         :type WordInfo: int
         :param HotwordId: 热词id。用于调用对应的热词表，如果在调用语音识别服务时，不进行单独的热词id设置，自动生效默认热词；如果进行了单独的热词id设置，那么将生效单独设置的热词id。
         :type HotwordId: str
+        :param AudioData: 回调数据中，是否需要对应音频数据。
+        :type AudioData: bool
         """
         self.EngineType = None
         self.Url = None
@@ -222,6 +224,7 @@ class CreateAsyncRecognitionTaskRequest(AbstractModel):
         self.ConvertNumMode = None
         self.WordInfo = None
         self.HotwordId = None
+        self.AudioData = None
 
 
     def _deserialize(self, params):
@@ -235,6 +238,7 @@ class CreateAsyncRecognitionTaskRequest(AbstractModel):
         self.ConvertNumMode = params.get("ConvertNumMode")
         self.WordInfo = params.get("WordInfo")
         self.HotwordId = params.get("HotwordId")
+        self.AudioData = params.get("AudioData")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1163,7 +1167,6 @@ class SentenceRecognitionRequest(AbstractModel):
 • 16k_en：16k 英语；
 • 16k_ca：16k 粤语；
 • 16k_ja：16k 日语；
-• 16k_wuu-SH：16k 上海话方言；
 • 16k_zh_medical：16k 医疗；
 • 16k_zh_dialect：多方言。
         :type EngSerViceType: str
@@ -1189,7 +1192,7 @@ class SentenceRecognitionRequest(AbstractModel):
         :type FilterPunc: int
         :param ConvertNumMode: 是否进行阿拉伯数字智能转换。0：不转换，直接输出中文数字，1：根据场景智能转换为阿拉伯数字。默认值为1。
         :type ConvertNumMode: int
-        :param WordInfo: 是否显示词级别时间戳。0：不显示；1：显示，不包含标点时间戳，2：显示，包含标点时间戳。支持引擎8k_zh，16k_zh，16k_en，16k_ca，16k_ja，16k_wuu-SH。默认值为 0。
+        :param WordInfo: 是否显示词级别时间戳。0：不显示；1：显示，不包含标点时间戳，2：显示，包含标点时间戳。默认值为 0。
         :type WordInfo: int
         """
         self.ProjectId = None
@@ -1434,6 +1437,9 @@ class TaskStatus(AbstractModel):
         :param ResultDetail: 识别结果详情，包含每个句子中的词时间偏移，一般用于生成字幕的场景。(录音识别请求中ResTextFormat=1时该字段不为空)
 注意：此字段可能返回 null，表示取不到有效值。
         :type ResultDetail: list of SentenceDetail
+        :param AudioDuration: 音频时长(秒)。
+注意：此字段可能返回 null，表示取不到有效值。
+        :type AudioDuration: float
         """
         self.TaskId = None
         self.Status = None
@@ -1441,6 +1447,7 @@ class TaskStatus(AbstractModel):
         self.Result = None
         self.ErrorMsg = None
         self.ResultDetail = None
+        self.AudioDuration = None
 
 
     def _deserialize(self, params):
@@ -1455,6 +1462,7 @@ class TaskStatus(AbstractModel):
                 obj = SentenceDetail()
                 obj._deserialize(item)
                 self.ResultDetail.append(obj)
+        self.AudioDuration = params.get("AudioDuration")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
